"use strict";
/*
 * Copyright 2021 NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZipUtils = void 0;
const StreamZip = require("node-stream-zip");
const logger_1 = require("../logger");
const LoggerFactory_1 = require("../logger/LoggerFactory");
const BootstrapUtils_1 = require("./BootstrapUtils");
const logger = LoggerFactory_1.default.getLogger(logger_1.LogType.System);
class ZipUtils {
    static unzip(zipFile, innerFolder, targetFolder) {
        const zip = new StreamZip({
            file: zipFile,
            storeEntries: true,
        });
        logger.info(`Unzipping Backup Sync's '${innerFolder}' into '${targetFolder}'. This could take a while!`);
        let totalFiles = 0;
        let process = 0;
        return new Promise((resolve, reject) => {
            zip.on('entry', (entry) => {
                if (!entry.isDirectory && totalFiles) {
                    process++;
                    const percentage = ((process * 100) / totalFiles).toFixed(2);
                    const message = `${percentage}% | ${process} files unzipped out of ${totalFiles}`;
                    BootstrapUtils_1.BootstrapUtils.logSameLineMessage(message);
                }
                if (BootstrapUtils_1.BootstrapUtils.stopProcess) {
                    zip.close();
                    console.log();
                    reject(new Error('Process cancelled!'));
                }
            });
            zip.on('ready', () => {
                totalFiles = zip.entriesCount;
                zip.extract(innerFolder, targetFolder, (err) => {
                    zip.close();
                    if (err) {
                        console.log();
                        reject(err);
                    }
                    else {
                        console.log();
                        logger.info(`Unzipped '${targetFolder}' created`);
                        resolve();
                    }
                });
            });
        });
    }
}
exports.ZipUtils = ZipUtils;
